import numbers

import numpy as np

from .base import Distribution


class Debye(Distribution):
    name = 'Debye'

    @staticmethod
    def correlation(t, tau0, *args):
        return np.exp(-t/tau0)

    @staticmethod
    def susceptibility(omega, tau0, *args):
        return 1/(1 + 1j*omega*tau0)

    @staticmethod
    def specdens(omega, tau0, *args):
        return tau0 / (1 + (omega*tau0)**2)

    @staticmethod
    def distribution(taus, tau0, *args):
        if isinstance(taus, numbers.Number):
            return 1 if taus == tau0 else 0

        ret_val = np.zeros_like(taus)
        ret_val[np.argmin(abs(taus - tau0))] = 1
        return ret_val
