from ...io.bds_reader import BDSReader

from ..Qt import QtCore, QtWidgets
from .._py.bdsdialog import Ui_Dialog


class QBDSReader(QtWidgets.QDialog, Ui_Dialog):
    data_read = QtCore.pyqtSignal(list)
    file_ext = ['.eps']

    def __init__(self, fname: str = None, parent=None):
        super().__init__(parent=parent)
        self.setupUi(self)

        if fname is not None:
            self.reader = BDSReader(fname)
            self.setup_gui()

    def __call__(self, fname: str):
        self.reader = BDSReader(fname)
        self.setup_gui()

        return self

    def setup_gui(self):
        self.listWidget.clear()

        for temp in self.reader.set_temp:
            item = QtWidgets.QListWidgetItem(str(temp))
            item.setFlags(QtCore.Qt.ItemIsEnabled | QtCore.Qt.ItemIsUserCheckable | QtCore.Qt.ItemIsSelectable)
            item.setCheckState(QtCore.Qt.Checked)
            self.listWidget.addItem(item)

    def accept(self):
        data = []

        temps = []
        for i in range(self.listWidget.count()):
            item = self.listWidget.item(i)
            if item.checkState() == QtCore.Qt.Checked:
                temps.append(i)

        for (mode, cb) in [('epsilon', self.eps_checkBox),
                           ('sigma', self.cond_checkBox),
                           ('modulus', self.modul_checkBox)]:

            if cb.checkState() == QtCore.Qt.Checked:
                values = self.reader.export(mode=mode)
                for t in temps:
                    data.append(values[t])

        self.data_read.emit(data)

        super().accept()


if __name__ == '__main__':
    import sys

    app = QtWidgets.QApplication(sys.argv)

    reader = QBDSReader()
    reader('/autohome/dominik/nmreval/testdata/ZWEITECHANCE_EGD4H2O.EPS')
    reader.show()
    sys.exit(app.exec())

